# OpenMapFlow Project

[Detailed documentation](https://github.com/nasaharvest/openmapflow/blob/main/README.md)

[cb]: https://colab.research.google.com/assets/colab-badge.svg
[1]: https://colab.research.google.com/github/nasaharvest/openmapflow/blob/main/openmapflow/notebooks/new_data.ipynb
[2]: https://colab.research.google.com/github/nasaharvest/openmapflow/blob/main/openmapflow/notebooks/train.ipynb
[3]: https://colab.research.google.com/github/nasaharvest/openmapflow/blob/main/openmapflow/notebooks/create_map.ipynb

| Adding data  | Training a model | Creating a map |
| ------------ | ---------------- | -------------- |
| [![cb]][1]   | [![cb]][2]       | [![cb]][3]     |